# -*- coding: utf-8 -*-
"""
Enterprise Data Django application initialization.
"""

from django.apps import AppConfig


class EnterpriseDataAppConfig(AppConfig):
    """
    Configuration for the enterprise Django application.
    """

    name = "enterprise_data"
